==> bytecode-disassembler_2.11-0.8.10-sources.jar: org/opalj/da/ParametersAnnotations_attribute.scala <==
/* BSD 2-Clause License:
 * Copyright (c) 2009 - 2017
 * Software Technology Group
 * Department of Computer Science
 * Technische Universität Darmstadt
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.opalj
package da

import scala.xml.Node

/**
 * @author Michael Eichberg
 * @author Wael Alkhatib
 * @author Isbel Isbel
 * @author Noorulla Sharief
 * @author Andre Pacak
 */
trait ParametersAnnotations_attribute extends Attribute {

    final override def attribute_length =
        parameters_annotations.foldLeft(1 /*num_parameters*/ ) { (c, n) ⇒
            c + n.foldLeft(2 /*num_annotations*/ )((c, n) ⇒ c + n.attribute_length)
        }

    type ParameterAnnotations = IndexedSeq[da.Annotation]

    type ParametersAnnotations = IndexedSeq[ParameterAnnotations]

    def parameters_annotations: ParametersAnnotations

    def annotationstoXHTML(implicit cp: Constant_Pool): Node = {
        val ans = {
            for { // TODO This doesn't make sense: it is no longer possible to distinguish parameters
                perParameterAnnotations ← parameters_annotations
                annotation ← perParameterAnnotations
            } yield annotation.toXHTML(cp)
        }

        <span>{ ans }</span>
    }
}

==> bytecode-disassembler_2.11-0.8.15-sources.jar: org/opalj/da/ParametersAnnotations_attribute.scala <==
/* BSD 2-Clause License:
 * Copyright (c) 2009 - 2017
 * Software Technology Group
 * Department of Computer Science
 * Technische Universität Darmstadt
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.opalj
package da

import scala.xml.Node

/**
 * @author Michael Eichberg
 * @author Wael Alkhatib
 * @author Isbel Isbel
 * @author Noorulla Sharief
 * @author Andre Pacak
 */
trait ParametersAnnotations_attribute extends Attribute {

    final override def attribute_length = {
        parameters_annotations.foldLeft(1 /*num_parameters*/ ) { (c, n) ⇒
            c + n.foldLeft(2 /*num_annotations*/ )((c, n) ⇒ c + n.attribute_length)
        }
    }

    type ParameterAnnotations = IndexedSeq[da.Annotation]

    type ParametersAnnotations = IndexedSeq[ParameterAnnotations]

    def parameters_annotations: ParametersAnnotations

    def parametersAnnotationstoXHTML(implicit cp: Constant_Pool): Node = {
        val ans = {
            for { // TODO This doesn't make sense: it is no longer possible to distinguish parameters
                (perParameterAnnotations, parameterIndex) ← parameters_annotations.zipWithIndex
                annotation ← perParameterAnnotations
            } yield annotation.toXHTML(cp)
        }

        <div>{ ans }</div>
    }
}
